@@ -35,15 +35,6 @@ class CoverPosMessage(Message):
         self.channel = self.byte_to_channel(data[0])
         self.position = data[1]
 
-    def to_json(self):
-        """
-        :return: str
-        """
-        json_dict = self.to_json_basic()
-        json_dict["channel"] = self.channel
-        json_dict["position"] = self.position
-        return json.dumps(json_dict)
-
     def set_defaults(self, address):
         if address is not None:
             self.set_address(address)
