@@ -46,19 +46,6 @@ class KwhStatusMessage(Message):
         if self.watt < 55:
             self.watt = 0
 
-    def to_json(self):
-        """
-        :return: str
-        """
-        json_dict = self.to_json_basic()
-        json_dict["pulses"] = self.pulses
-        json_dict["counter"] = self.counter
-        json_dict["kwh"] = self.kwh
-        json_dict["delay"] = self.delay
-        json_dict["watt"] = self.watt
-        json_dict["channel"] = self.channel
-        return json.dumps(json_dict)
-
     def get_channels(self):
         """
         :return: list
